summaryrefslogtreecommitdiff
path: root/starmath/source/visitors.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'starmath/source/visitors.cxx')
-rw-r--r--starmath/source/visitors.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/starmath/source/visitors.cxx b/starmath/source/visitors.cxx
index 7e02d4739c62..6a341084f06b 100644
--- a/starmath/source/visitors.cxx
+++ b/starmath/source/visitors.cxx
@@ -495,8 +495,8 @@ void SmDrawingVisitor::DrawTextNode( SmTextNode* pNode )
void SmDrawingVisitor::DrawSpecialNode( SmSpecialNode* pNode )
{
//! since this chars might come from any font, that we may not have
- //! set to ALIGN_BASELINE yet, we do it now.
- pNode->GetFont( ).SetAlignment( ALIGN_BASELINE );
+ //! set to TextAlign::Baseline yet, we do it now.
+ pNode->GetFont( ).SetAlignment( TextAlign::Baseline );
DrawTextNode( pNode );
}